#body {
	margin:auto;
	clear:auto;
}
#content {
}

.container {
	margin:auto;
	padding: 0px;
	max-width: 60em;
}

table.container {
	border: white;
	borer-collapse: collapse;
	padding: 0px;
}
td.container {
	border: white;
	padding: 0px;
}


.message { color:#347235; font-style:italic; }
.error_message { color:#800517; font-weight: bold; }
.error { color:#800517; }


table {
	border-collapse: collapse; 
}
#all_player_home {
	font-size: 1.33em;
}
table.all_player_home { 
	border: none; 
	font: arial, helvetica, verdana, sans-serif; 
} 

.all_player_home th { 
	vertical-align: middle; 
	border: solid thin #d4d4d4;
} 

.all_player_home td { 
	vertical-align: middle; 
	border: solid thin #d4d4d4;
} 

/* Styles Regional Bracke */
td p { 
	border-bottom: solid thin black; 
	margin: 0; 
	padding: 5px 5px 2px 5px; 
	cursor: pointer;
} 


.out {
	text-decoration: line-through; 
	font-size: smaller;
}

.in {
	color: green;
}

.pending {}

.points {
	font-size: bigger; 
	color: chocolate;
}

.cash {
	color: darkgreen;
}

.odd {
	background-color: #f0f0f0;
}

.even {}

.user_header {
	float:right; 
	clear:right; 
}

.no_border {
	border: none;
}

.page_header {
	width: 100%;
}

td p:hover { background-color:cornsilk;  border: solid 1px black;}

table.regional_bracket {
	margin-left: 4em;
	margin-top: 1em;
	background: white;
}
.regional_bracket td { 
	vertical-align: middle;
/*	width: 12em; */ 
	margin: 0;
	padding: 0; 
} 

.region_name {
	font-weight: bold;
	text-align: left;
	background-color: #ffffcc;
}
#player_page_header {
	background: #cce0ff;
}
table#player_links_table { margin:auto; background-color: white;}
table#player_links_table td { 
	padding: 0.5em; 
	font-size: 1.2em; 
	border-right: thin gray solid;
	border-left: thin gray solid;
	border-top: thin gray solid;
}
#player_page {
	margin:auto; 
	text-align:center; 
	max-width:30em; 
	border:gray 1px solid; 
	background:#ffe5cc; 
	clear:both;
	font-size: 1.33em;
}

.admin_links {
	border: thin gray solid;
	background-color: #e5ffcc;
}

.player_name {
	font-style: italic;
	font-weight: bold;
	background-color: white;
	padding-right: 5px;
	padding-left: 3px;
	color: #990019;
	border-bottom: grey thin solid;
	border-right: grey thin solid;
	border-left: grey thin solid;
}
.register_link {
	font-size: 1.08em;
	background-color: #ffffcc;
	border: thin solid grey;
	max-width: 13em;
	padding: 3px;
}

.separator {
    font-size: 0.72em; 
    color: gray; 
    vertical-align: 20%;
}

h1 {
	border: thin solid grey;
	font-size: 1.66em;
	padding: 3px;
	background-color: cornsilk;
}